# pylint: disable=redefined-builtin
# pylint: disable=wildcard-import
from .lists import *
from .dicts import *

__version__ = "0.3.1"

__title__ = "nicetypes"
__description__ = "Advanced types for Python3"
__uri__ = "https://github.com/tvuillemin/nicetypes"
__doc__ = __description__ + " <" + __uri__ + ">"

__author__ = "Thibaut Vuillemin"
__email__ = "contact@thibautvuillemin.com"

__license__ = "MIT"
__copyright__ = "Copyright (c) 2017 Thibaut Vuillemin"
